@@ -8,7 +8,7 @@ import tempfile
 import typing
 from fp.fp import FreeProxy
 from datetime import date
-from typing import Any, Optional, Union
+from typing import Any, Dict, List, Optional, Union
 
 import requests
 from requests.models import Response
@@ -33,14 +33,19 @@ class Client:
     TEMP_DIR = os.path.join(tempfile.gettempdir(), "Supermarket-Connector", "Debug", "JUMBO")
 
     def request(
-        self, method: str, end_point: str, headers: dict[str, Any] = {}, params: dict[str, Any] = {}, timeout: int = 10, json_: bool = True, debug_key: Optional[str] = None
-    ) -> Union[list[Any], dict[Any, Any], str]:
+        self, method: str, end_point: str, headers: Dict[str, Any] = {}, params: Dict[str, Any] = {}, timeout: int = 10, json_: bool = True, debug_key: Optional[str] = None
+    ) -> Union[List[Any], Dict[Any, Any], str]:
 
         headers.update(self.DEFAULT_HEADERS)
         counter_tries = 0
+        new_proxy = False
 
         while True:
             try:
+                if new_proxy:
+                    new_proxy = False
+                    self.__proxy = FreeProxy().get()
+
                 counter_tries += 1
                 response: Response = requests.request(method, f"{self.BASE_URL}{end_point}", params=params, headers=headers, timeout=timeout, proxies={"http": self.__proxy})
 
@@ -50,14 +55,14 @@ class Client:
                     continue
             except Exception as e:
                 print(e)
-                self.__proxy = FreeProxy().get()
+                new_proxy = True
                 continue
             else:
                 break
 
         if json_:
             try:
-                response_json: Union[list[Any], dict[Any, Any]] = response.json()
+                response_json: Union[List[Any], Dict[Any, Any]] = response.json()
 
                 if self.debug:
                     if self.debug_fn is None:
@@ -123,7 +128,7 @@ class Client:
     class Categories:
         def __init__(self, client: Client) -> None:
             self.__client = client
-            self.data: dict[int, Client.Category] = {}
+            self.data: Dict[Union[int, str], Client.Category] = {}
 
         def list(self):
             response = self.__client.request("GET", "v17/categories")
@@ -131,7 +136,7 @@ class Client:
             if not isinstance(response, dict):
                 raise ValueError("Reponse is not in right format")
 
-            data: list[dict[Any, Any]] = response.get("categories", {}).get("data", [])
+            data: List[Dict[Any, Any]] = response.get("categories", {}).get("data", [])
 
             for elem in data:
                 category = self.__client.Category(self.__client, data=elem)
@@ -141,15 +146,15 @@ class Client:
 
             return self.data
 
-        def get(self, id: Optional[int] = None, name: Optional[str] = None):
+        def get(self, id: Optional[Union[int, str]] = None, name: Optional[str] = None):
             if not id is None:
                 if id in self.data.keys():
-                    self.data[id]
+                    return self.data[id]
 
                 self.list()
 
                 if id in self.data.keys():
-                    self.data[id]
+                    return self.data[id]
 
             elif not name is None:
                 for category in self.data.values():
@@ -167,14 +172,14 @@ class Client:
     class Products:
         def __init__(self, client: Client) -> None:
             self.__client = client
-            self.data: dict[int, dict[str, Client.Product]] = {}
+            self.data: Dict[Union[int, str], Dict[str, Client.Product]] = {}
 
         @typing.overload
-        def list(self) -> dict[int, dict[str, Client.Product]]:
+        def list(self) -> Dict[Union[int, str], Dict[str, Client.Product]]:
             ...
 
         @typing.overload
-        def list(self, category: Client.Category) -> dict[str, Client.Product]:
+        def list(self, category: Client.Category) -> Dict[str, Client.Product]:
             ...
 
         def list(self, category: Optional[Client.Category] = None):
@@ -209,7 +214,7 @@ class Client:
                     if total_pages == 0:
                         total_pages: int = math.ceil(response.get("products", {}).get("total", 30) / max_size)
 
-                    data: list[dict[Any, Any]] = response.get("products", {}).get("data", [])
+                    data: List[Dict[Any, Any]] = response.get("products", {}).get("data", [])
 
                     for product in data:
                         temp_ = self.__client.Product(self.__client, data=product)
@@ -228,15 +233,15 @@ class Client:
         def __init__(self, client: Client) -> None:
             self.__client = client
 
-        def process(self, data: list[dict[str, Any]]):
-            temp: list[Client.Image] = []
+        def process(self, data: List[Dict[str, Any]]):
+            temp: List[Client.Image] = []
             for elem in data:
                 temp.append(self.__client.Image(self.__client, data=elem))
 
             return temp
 
     class Product(Product):
-        def __init__(self, client: Client, id: Optional[int] = None, data: Optional[dict[str, Any]] = None) -> None:
+        def __init__(self, client: Client, id: Optional[int] = None, data: Optional[Dict[str, Any]] = None) -> None:
             self.__client = client
 
             if data is None and id is None:
@@ -251,10 +256,10 @@ class Client:
             super().__init__(id)
 
             if not data is None:
-                images_data: list[dict[str, Any]] = data.get("imageInfo", {}).get("primaryView", [])
-                quantity_data: dict[str, Any] = data.get("quantityOptions", [{}])[0]
-                price_data: dict[str, Any] = data.get("prices", {})
-                bonus_data: dict[str, Any] = data.get("promotion", {})
+                images_data: List[Dict[str, Any]] = data.get("imageInfo", {}).get("primaryView", [])
+                quantity_data: Dict[str, Any] = data.get("quantityOptions", [{}])[0]
+                price_data: Dict[str, Any] = data.get("prices", {})
+                bonus_data: Dict[str, Any] = data.get("promotion", {})
 
                 self.name = data.get("title")
                 self.unit_size = quantity_data.get("unit")
@@ -307,10 +312,10 @@ class Client:
             if not isinstance(response, dict):
                 raise ValueError("Expected value to be dict")
 
-            data: dict[str, Any] = response.get("product", {})
-            productCard: dict[str, Any] = data.get("data", {})
-            brand_data: dict[str, Any] = productCard.get("brandInfo", {})
-            # alergy_data: list[str] = productCard.get("allergyText", "").split(",")
+            data: Dict[str, Any] = response.get("product", {})
+            productCard: Dict[str, Any] = data.get("data", {})
+            brand_data: Dict[str, Any] = productCard.get("brandInfo", {})
+            # alergy_data: List[str] = productCard.get("allergyText", "").split(",")
 
             self.category = productCard.get("topLevelCategory")
             self.category_id = productCard.get("topLevelCategoryId")
@@ -334,16 +339,16 @@ class Client:
                 return self.price_raw
 
     class Category(Category):
-        subs: list[Client.Category]
-        images: list[Client.Image]
+        subs: List[Client.Category]
+        images: List[Client.Image]
 
         def __init__(
             self,
             client: Client,
-            id: Optional[int] = None,
+            id: Optional[Union[int, str]] = None,
             name: Optional[str] = None,
             image: Optional[Client.Image] = None,
-            data: Optional[dict[str, Any]] = None,
+            data: Optional[Dict[str, Any]] = None,
         ) -> None:
             self.__client = client
 
@@ -364,7 +369,8 @@ class Client:
             if id is None:
                 raise ValueError("Expected data to have ID")
 
-            id = int(id)
+            if id.isdigit():
+                id = int(id)
 
             super().__init__(id, slug_name, name, images=[image], subs=[])
 
@@ -385,7 +391,7 @@ class Client:
 
             return self.subs
 
-        def lookup(self, id: Optional[int] = None, name: Optional[str] = None) -> Optional[Client.Category]:
+        def lookup(self, id: Optional[Union[int, str]] = None, name: Optional[str] = None) -> Optional[Client.Category]:
             if not id is None:
                 if self.id == id:
                     return self
@@ -425,7 +431,7 @@ class Client:
             self,
             client: Client,
             url: Optional[str] = None,
-            data: Optional[dict[str, Any]] = None,
+            data: Optional[Dict[str, Any]] = None,
         ) -> None:
             super().__init__()
             self.client = client
